@@ -8,24 +8,16 @@ from pprint import pformat
 
 import pandas as pd
 
-from dgraphpandas import __version__
+from dgraphpandas import __version__, __description__
 from dgraphpandas.strategies.horizontal import horizontal_transform
 from dgraphpandas.strategies.vertical import vertical_transform
 from dgraphpandas.writers.upserts import generate_upserts
 
-logger = logging.getLogger(__name__)
-
-try:
-    import coloredlogs
-    coloredlogs.install(level='DEBUG')
-except ImportError as e:
-    logger.warning(e)
-
 pd.set_option('mode.chained_assignment', None)
 
 
 def main():
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(description=__description__)
     parser.add_argument('-f', '--file', required=True, help='The Data File (CSV) to convert into RDF.')
     parser.add_argument('-c', '--config', required=True, help='The DgraphPandas Configuration. See Documentation for options/examples.')
     parser.add_argument('-ck', '--config_file_key', required=True, help='The Entry in the Configuration to use for this passed file.')
@@ -33,7 +25,7 @@ def main():
     parser.add_argument('--console', action='store_true', default=False, help='Write the Preprocessed DataFrames to console (for debugging)')
     parser.add_argument('--pre_csv', action='store_true', default=False, help='Write the Preprocessed DataFrame to CSV (for debugging)')
     parser.add_argument('--skip_upsert_generation', action='store_true', default=False, help="Don't generate RDF files")
-    parser.add_argument('--encoding', default=os.environ.get('DGRAPH_PANDAS_ENCODING', 'utf-8'), help='The Encoding to write files.')
+    parser.add_argument('--encoding', default=os.environ.get('DGRAPHPANDAS_ENCODING', 'utf-8'), help='The Encoding to write files.')
     parser.add_argument('--chunk_size', default=10_000_000, type=int, help='Process and output in chunks rather all at once')
     parser.add_argument('--gz_compression_level', default=9, type=int, help='Compression level to set output gzip files to')
     parser.add_argument('--key_separator')
@@ -43,9 +35,21 @@ def main():
     parser.add_argument('--illegal_characters', default=['%', '\\.', '\\s', '\"', '\\n', '\\r\\n'])
     parser.add_argument('--illegal_characters_intrinsic_object', default=['\"', '\\n', '\\r\\n'])
     parser.add_argument('--version', action='version', version=__version__)
+    parser.add_argument('-v', '--verbosity',
+                        choices=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'NOTSET'],
+                        default=os.environ.get('DGRAPHPANDAS_LOG', 'INFO'))
 
     args = parser.parse_args()
 
+    logging.basicConfig(level=args.verbosity)
+    logger = logging.getLogger(__name__)
+
+    try:
+        import coloredlogs
+        coloredlogs.install(level=args.verbosity)
+    except ImportError as e:
+        logger.debug(e)
+
     with open(args.config, 'r') as f:
         global_config: Dict[str, Any] = json.load(f)
         logger.debug('Global Config \n %s', pformat(global_config))
